@@ -13,7 +13,6 @@ OC.L10N.register(
     "Go back" : "ফিরে যাও",
     "Cancel" : "বাতির",
     "General" : "সাধারণ",
-    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
     "Delete" : "মুছে",
     "Search" : "Search",
     "Send" : "পাঠাও",
@@ -32,6 +31,7 @@ OC.L10N.register(
     "Comment" : "মন্তব্য",
     "Remove" : "অপসারণ",
     "Today" : "আজ",
+    "Favorites" : "প্রিয়জন",
     "Other" : "অন্যান্য",
     "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
     "Move" : "Move",
@@ -44,6 +44,7 @@ OC.L10N.register(
     "Close" : "বন্ধ",
     "Date" : "Date",
     "Tags" : "ট্যাগ",
+    "Deleted" : "মুছে ফেলা",
     "Help" : "সহায়িকা",
     "Actions" : "পদক্ষেপসমূহ",
     "delete" : "মুছে ফেল",
@@ -56,8 +57,6 @@ OC.L10N.register(
     "Group" : "গোষ্ঠীসমূহ",
     "Shared" : "ভাগাভাগিকৃত",
     "Shares" : "ভাগাভাগি",
-    "All" : "সবাই",
-    "Favorites" : "প্রিয়জন",
-    "Accounts" : "Accounts"
+    "All" : "সবাই"
 },
 "nplurals=2; plural=(n != 1);");
