@@ -28,13 +28,11 @@ OC.L10N.register(
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Register" : "Registrar",
-    "About" : "Acerca de",
-    "Keyboard shortcuts" : "Atajos del teclado",
+    "Add mail account" : "Agregar cuenta de correo",
+    "Newest first" : "Más reciente primero",
+    "Oldest first" : "Más antiguo primero",
+    "Security" : "Seguridad",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
     "Older message" : "Mensaje más antiguo",
@@ -45,6 +43,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "About" : "Acerca de",
     "Ok" : "Ok",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
@@ -68,8 +67,8 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Remove" : "Eliminar",
-    "email" : "correo electrónico",
     "Today" : "Hoy",
+    "Favorites" : "Favoritos",
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
@@ -101,6 +100,7 @@ OC.L10N.register(
     "Select tags" : "Selecciona las etiquetas",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
+    "Deleted" : "Borrado",
     "Recipient" : "Destinatario",
     "Help" : "Ayuda",
     "matches" : "coincide",
@@ -123,7 +123,6 @@ OC.L10N.register(
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
     "Inbox" : "Buzón de entrada",
     "Junk" : "Basura",
