@@ -20,9 +20,11 @@ OC.L10N.register(
     "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Saatja aadress %1$s pole aadressiraamatus, aga %2$s nimi on ning temaga on seotud järgnevad aadressid: %3$s",
     "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Saatja kasutab muudetud e-postiaadressi %1$s oma tavalise %2$s aadressi asemel",
     "Sent date is in the future" : "Saatmise kuupäev on tulevikus",
+    "Mail server marked this message as phishing attempt" : "E-posti server märkis selle e-kirja õngitsuskatseks",
     "Some addresses in this message are not matching the link text" : "Mõned selle kirja aadressid ei vasta lingi tekstile",
     "Reply-To email: %1$s is different from sender email: %2$s" : "Vastamiseks mõeldud e-posti aadress: %1$s on erinev saatja aadressist %2$s",
     "Mail connection performance" : "E-postiteenuse ühenduse jõudlus",
+    "Mail account parameters, aliases and preferences" : "E-posti kasutajakonto parameetrid, aliased ja eelistused",
     "💌 A mail app for Nextcloud" : "💌 E-postirakendus Nextcloudi jaoks",
     "Your session has expired. The page will be reloaded." : "Sinu sessioon on aegunud. Leht saab olema uuesti laaditud.",
     "Drafts are saved in:" : "Kirjade kavandis on salvestatud siia:",
@@ -54,6 +56,10 @@ OC.L10N.register(
     "SMTP server is not reachable" : "SMTP server pole leitav",
     "IMAP username or password is wrong" : "IMAP-i kasutajanimi või salasõna on valed",
     "SMTP username or password is wrong" : "SMTP kasutajanimi või salasõna on valed",
+    "IMAP server denied authentication" : "IMAP-i server keeldus autentimisest",
+    "SMTP server denied authentication" : "SMTP server keeldus autentimisest",
+    "IMAP authentication error" : "IMAP-i autentimisviga",
+    "SMTP authentication error" : "SMTP autentimisviga",
     "IMAP connection failed" : "IMAP-i ühendust ei õnnestunud luua",
     "SMTP connection failed" : "SMTP ühendust ei õnnestunud luua",
     "Authorization pop-up closed" : "Autentimise hüpikaken on suletud",
@@ -98,6 +104,7 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automaatsed vastused saabunud kirjadele. Kui keegi saadab sulle enam  kui ühe kirja, siis saab ta automaatse vastuse kord 4 päeva jooksul.",
     "The autoresponder uses Sieve, a scripting language supported by many email providers. If you're unsure whether yours does, check with your provider. If Sieve is available, click the button to go to the settings and enable it." : "Automaatvastaja on loodud Sieve skriptimiskeeles ja tavaliselt on selline võimalus toetatud paljude e-posti teenuste puhul. Kui sa pole enda omas kindel, siis palun küsi neilt üle. Kui Sieve on kasutatav, siis klõpsi järgnevat nuppu ja võta ta seadistustest kasutusele.",
     "Go to Sieve settings" : "Ava Sieve seadistused",
+    "Calendar settings" : "Kalendri seadistused",
     "Classification settings" : "Klassifitseerimise seadistused",
     "Filters" : "Filtrid",
     "Quick actions" : "Kiirtoimingud",
@@ -133,6 +140,7 @@ OC.L10N.register(
     "Vertical split" : "Püstjoones jagamine",
     "Horizontal split" : "Rõhtjoones jagamine",
     "List" : "Nimekiri",
+    "Use compact mode" : "Kasuta kompaktset vaadet",
     "Sorting" : "Järjestus",
     "Newest first" : "Uuemad eespool",
     "Oldest first" : "Vanemad eespool",
@@ -159,9 +167,6 @@ OC.L10N.register(
     "Step 2" : "2. samm",
     "Enable for the current domain" : "Luba  kasutamine selle domeeni puhul",
     "Assistance features" : "Abilise funktsionaalsused",
-    "About" : "Rakenduse teave",
-    "Acknowledgements" : "Tänuavaldused",
-    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
     "Compose new message" : "Koosta uus kiri",
     "Newer message" : "Uuem kiri",
     "Older message" : "Vane kiri",
@@ -172,6 +177,9 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
+    "About" : "Rakenduse teave",
+    "Acknowledgements" : "Tänuavaldused",
+    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
     "Title of the text block" : "Tekstiploki pealkiri",
     "Content of the text block" : "Tekstiploki sisu",
     "Ok" : "Sobib",
@@ -365,7 +373,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
     "Choose target folder" : "Vali sihtkaust",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
-    "Messages that your mark as favorite will be shown at the top of folders. You can disable this behavior in the app settings" : "Lemmikuks märgitud kirjad järjestuvad kaustas esimestena. Selle valiku saad seadistustest välja lülitada.",
     "Favorites" : "Lemmikud",
     "Favorites info" : "Lemmikute teave",
     "Load more favorites" : "Laadi veel lemmikuid",
