@@ -93,6 +93,7 @@ OC.L10N.register(
     "Days after which messages in Trash will automatically be deleted:" : "Zaborrontziko mezuak automatikoki ezabatuko dira hainbat egunen ostean:",
     "Autoresponder" : "Autoerantzulea",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Sarrerako mezuei erantzun automatikoa. Norbaitek hainbat mezu bidaltzen badizu, erantzun automatizatu hau gehienez 4 egunean behin bidaliko da.",
+    "Calendar settings" : "Egutegiaren ezarpenak",
     "Filters" : "Iragazkiak",
     "Sieve script editor" : "Sieve script editorea",
     "Mail server" : "Posta-zerbitzaria",
@@ -128,7 +129,6 @@ OC.L10N.register(
     "Manage certificates" : "Kudeatu ziurtagiriak",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Laguntzailearen aukerak",
-    "About" : "Honi buruz",
     "Compose new message" : "Idatzi mezu berria",
     "Newer message" : "Mezu berriagoa",
     "Older message" : "Mezu zaharragoa",
@@ -139,6 +139,7 @@ OC.L10N.register(
     "Search" : "Bilatu",
     "Send" : "Bidali",
     "Refresh" : "Freskatu",
+    "About" : "Honi buruz",
     "Ok" : "Ados",
     "No certificate" : "Ziurtagiririk ez",
     "Certificate updated" : "Ziurtagiria eguneratu da",
@@ -372,6 +373,7 @@ OC.L10N.register(
     "Collapse folders" : "Bildu karpetak",
     "_{total} message_::_{total} messages_" : ["Mezu {total}","{total} mezu"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} irakurri gabe {total} -etik","{unread} irakurri gabe {total} -etik"],
+    "Loading …" : "Kargatzen …",
     "All messages in mailbox will be deleted." : "Postontziko mezu guztiak ezabatuko dira.",
     "Clear mailbox {name}" : "Garbitu {name} postontzia",
     "The folder and all messages in it will be deleted." : " \nKarpeta eta bertan dauden mezu guztiak ezabatuko dira.",
