@@ -19,31 +19,36 @@ OC.L10N.register(
     "Signature" : "Tanda",
     "Filters" : "Penyaring",
     "Go back" : "Kembali",
+    "Change name" : "Ubah nama",
     "Email address" : "Alamat email",
     "Cancel" : "Membatalkan",
     "General" : "Umum",
     "Add mail account" : "Tambahkan akun email",
     "Appearance" : "Tampilan",
     "List" : "Daftar",
+    "Sorting" : "Pengurutan",
     "Newest first" : "Terbaru",
     "Oldest first" : "Paling lama",
     "Shared with me" : "Dibagikan dengan saya",
+    "Privacy" : "Privasi",
     "Security" : "Keamanan",
-    "About" : "Tentang",
     "Archive" : "Arsip",
     "Delete" : "Hapus",
     "Search" : "Cari",
     "Send" : "Kirim",
     "Refresh" : "Segarkan",
+    "About" : "Tentang",
     "Ok" : "Oke",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
     "Choose" : "Pilih",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Confirm" : "Konfirmasi",
+    "Unfavorite" : "Hapus dari favorit",
     "Favorite" : "Favorit",
     "Read" : "Baca",
     "Edit tags" : "Sunting label",
+    "More actions" : "Tindakan lainnya",
     "Back" : "Kembali",
     "Mark as unread" : "Tandai belum dibaca",
     "Mark as read" : "tandai sudah dibaca",
@@ -58,6 +63,7 @@ OC.L10N.register(
     "Decline" : "Tolak",
     "Remove" : "Buang",
     "Today" : "Hari ini",
+    "Yesterday" : "Kemarin",
     "Last week" : "Minggu lalu",
     "Last month" : "Bulan lalu",
     "Choose target folder" : "Pilih folder target",
@@ -70,8 +76,11 @@ OC.L10N.register(
     "Download attachment" : "Unduh lampiran",
     "Move" : "Pindah",
     "Remove account" : "Hapus akun",
+    "Add folder" : "Tambah folder",
     "Folder name" : "Nama folder",
     "Saving" : "Menyimpan",
+    "Loading …" : "Memuat …",
+    "Delete folder" : "Hapus folder",
     "Mark all as read" : "Tandai semua telah dibaca",
     "Rename" : "Ubah nama",
     "Clear cache" : "Bersihkan cache",
@@ -79,6 +88,7 @@ OC.L10N.register(
     "Draft" : "Draf",
     "Reply" : "Balas",
     "Retry" : "Ulangi",
+    "First day" : "Hari pertama",
     "Message" : "Pesan",
     "Copy to clipboard" : "Salin ke papan klip",
     "Add" : "Masukkan",
@@ -90,6 +100,7 @@ OC.L10N.register(
     "Custom" : "Ubahan",
     "Tag already exists" : "Tag sudah ada",
     "Add tag" : "Tambahkan tag",
+    "Not found" : "Tidak ditemukan",
     "Unsubscribe" : "Berhenti berlangganan",
     "Untitled event" : "Acara tanpa judul",
     "(organizer)" : "(penyelenggara)",
@@ -110,6 +121,7 @@ OC.L10N.register(
     "Port" : "Port",
     "Valid until" : "Berlaku sampai",
     "Certificate" : "Sertifikat",
+    "Submit" : "Kirim",
     "Guest" : "Tamu",
     "Group" : "Grup",
     "Shared" : "Dibagikan",
@@ -128,6 +140,7 @@ OC.L10N.register(
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
-    "Continue to %s" : "Lanjutkan ke %s"
+    "Continue to %s" : "Lanjutkan ke %s",
+    "Last 7 days" : "7 hari terakhir"
 },
 "nplurals=1; plural=0;");
