@@ -16,7 +16,7 @@ OC.L10N.register(
     "List" : "Tabdart",
     "Newest first" : "Imaynuten d imezwura",
     "Oldest first" : "Iqbuṛen d imezwura",
-    "Keyboard shortcuts" : "Inegzumen n unasiw",
+    "Privacy" : "Vie privée",
     "Delete" : "Kkes",
     "Search" : "Nadi",
     "Send" : "Tuzna",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Remove" : "Kkes",
     "Today" : "Ass-a",
     "Yesterday" : "Iḍelli",
+    "Favorites" : "Imenyafen",
     "Other" : "Wayeḍ",
     "Forward" : "Avancer",
     "Translate" : "Suqel",
@@ -57,10 +58,10 @@ OC.L10N.register(
     "Close" : "Mdel",
     "Date" : "Azemz",
     "Tags" : "Tibzimin",
-    "Last 7 days" : "7 n wussan yezrin",
     "Not found" : "Ulac-it",
     "Translate from" : "Suqel seg",
     "Translate to" : "Suqel ar",
+    "Deleted" : "Yettwakkes",
     "Help" : "Tallalt",
     "Actions" : "Tigawin",
     "Edit" : "Ẓreg",
@@ -69,12 +70,10 @@ OC.L10N.register(
     "Group" : "Agraw",
     "Account connected" : "Amiḍan d uqqin",
     "All" : "Akk",
-    "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
     "Nextcloud Mail" : "Imayl n Nextcloud",
     "Message sent" : "Izen yettwazen",
     "Continue to %s" : "Kemmel ar %s",
-    "Accounts" : "Imiḍanen",
-    "Loading …" : "Asali ..."
+    "Last 7 days" : "7 n wussan yezrin"
 },
 "nplurals=2; plural=(n != 1);");
