@@ -16,6 +16,7 @@ OC.L10N.register(
     "Manual" : "Manual",
     "None" : "Hakuna",
     "Signature" : "Saini",
+    "Calendar settings" : "Mipangilio ya kalenda",
     "Filters" : "Filters",
     "Go back" : "Rudi nyuma",
     "Change name" : "Change name",
@@ -31,18 +32,19 @@ OC.L10N.register(
     "Shared with me" : "Shared with me",
     "Privacy" : "Faragha",
     "Security" : "Ulinzi",
-    "About" : "Kuhusu",
     "Archive" : "Weka kumbukumbu",
     "Delete" : "Futa",
     "Search" : "Tafuta",
     "Send" : "Tuma",
     "Refresh" : "Refresh",
+    "About" : "Kuhusu",
     "Ok" : "Sawa",
     "From" : "Tangu/ kutoka",
     "Select account" : "Chagua akaunti",
     "To" : "Mpaka/ hadi",
     "Cc" : "Cc",
     "Subject" : "Subject",
+    "Draft saved" : "Draft saved",
     "Smart picker" : "Smart picker",
     "Choose" : "Chagua",
     "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
@@ -145,14 +147,17 @@ OC.L10N.register(
     "matches" : "matches",
     "Actions" : "Matendo",
     "Priority" : "Kipaumbele",
+    "Tag" : "Tag",
     "Edit" : "Hariri",
     "Reset" : "Pangilia upya",
     "Client ID" : "Kitambulisho cha mteja",
     "Client secret" : "Siri ya mteja",
+    "Unlink" : "Unlink",
     "User" : "Mtumiaji",
     "Host" : "Host",
     "Port" : "Port",
     "Valid until" : "Halali mpaka",
+    "Delete certificate" : "Delete certificate",
     "Certificate" : "Cheti",
     "Submit" : "Wasilisha",
     "Guest" : "Mgeni",
