@@ -10,18 +10,19 @@ OC.L10N.register(
     "Name" : "Name",
     "Password" : "Password",
     "None" : "Yo'q",
+    "Calendar settings" : "Taqvim sozlamalari",
     "Email address" : "E-pochta manzili",
     "Cancel" : "Bekor qilish",
     "General" : "Umumiy",
     "Appearance" : "Tashqi ko'rinish",
     "List" : "Ro`yxat",
     "Security" : "Xavfsizlik",
-    "About" : "About",
     "Archive" : "Arxiv",
     "Delete" : "O'chirish",
     "Search" : "Qidirish",
     "Send" : "Send",
     "Refresh" : "Refresh",
+    "About" : "About",
     "Ok" : "Yaxshi",
     "From" : "Dan",
     "To" : "Gacha",
@@ -78,6 +79,7 @@ OC.L10N.register(
     "Client ID" : "Mijoz identifikatori",
     "Port" : "Port",
     "Submit" : "Submit",
+    "Group" : "Guruh",
     "Shared" : "Ulashilgan",
     "Account connected" : "Akkaunt ulangan",
     "All" : "All",
